<?php
/**
 * Handles front-end.
 *
 * @since 0.1.0
 * @package ethpress
 */

namespace losnappas\Ethpress;

defined( 'ABSPATH' ) || die;

/**
 * Handles functions for frontend.
 *
 * @since 0.1.0
 */
class Front {

	/**
	 * Displays login button. Hooked to login_form.
	 *
	 * @since 0.1.0
	 */
	public static function login_form() {
		$img_alt  = esc_attr__( 'Install MetaMask', 'ethpress' );
		$img_src  = esc_attr( plugin_dir_url( ETHPRESS_FILE ) . 'public/images/download-metamask-dark-small-min.png' );
		$tooltip  = esc_html__( 'MetaMask is a cryptocurrency wallet for your browser.', 'ethpress' );
		$text     = esc_html__( 'Enable JavaScript to log in with MetaMask.', 'ethpress' );
		$noscript = '<noscript>' . $text . '</noscript>';

		// phpcs:disable -- Complains about $img_alt etc. not being escaped. They are.
		echo $noscript;
		?>
			<div class="ethpress">
				<?php echo self::get_login_button(); ?>
				<div class="ethpress-info-container">
					<i class="dashicons dashicons-info"></i>
					<div class="ethpress-info">
						<a href="https://metamask.io">
							<img src="<?php echo $img_src; ?>" alt="<?php echo $img_alt; ?>">
						</a>
						<p class="ethpress-tooltip-content">
							<?php echo $tooltip; ?>
						</p>
					</div>
				</div>
			</div>
		<?php
		// phpcs:enable
	}

	/**
	 * Gets the login form.
	 *
	 * @since 0.1.1
	 */
	public static function get_login_form() {
		\ob_start();
		self::login_form();
		return \ob_get_clean();
	}

	/**
	 * Creates necessary html for the login button.
	 *
	 * @since 0.1.0
	 *
	 * @return string Login button html.
	 */
	public static function get_login_button() {
		$label  = esc_html__( 'Log In with MetaMask', 'ethpress' );
		$button = "<button class='ethpress-metamask-login-button ethpress-button ethpress-button-secondary ethpress-button-large' type='button' name='metamask'>$label</button>";
		return $button;
	}

}
