<?php
/**
 * Has extras for signatures (message is signed -> signature).
 *
 * @since 0.1.0
 * @package ethpress
 */

namespace losnappas\Ethpress;

defined( 'ABSPATH' ) || die;

/**
 * Contains utility functions for signed messages.
 *
 * @since 0.1.0
 */
class Signature {

	/**
	 * Gets public address from signature. TODO check for failure.
	 *
	 * @since 0.1.0
	 *
	 * @param string $message   Message that was signed.
	 * @param string $signature Matching signature.
	 * @return (string|false)   The response data or false.
	 */
	public static function extract_address( $message, $signature ) {
		$defopts = [
			'api_url' => 'https://verify-eth-signature.herokuapp.com/ethpress',
		];
		$options = get_option( 'ethpress', $defopts );
		$api_url = $options['api_url'];
		$data    = [
			'message'   => $message,
			'signature' => $signature,
		];
		$args    = [
			'body'    => $data,
			'cookies' => [],
			'timeout' => 45,
		];

		$response = wp_remote_post(
			$api_url,
			$args
		);
		$body     = wp_remote_retrieve_body( $response );
		if ( ! empty( $body ) ) {
			$body = json_decode( $body );
			return $body->data;
		} else {
			return false;
		}
	}

	/**
	 * Verifies a signature.
	 *
	 * @since 0.1.0
	 *
	 * @param string $message   Message that was signed.
	 * @param string $signature Matching signature.
	 * @param string $coinbase  Public address used to sign the signature.
	 * @return bool
	 */
	public static function verify( $message, $signature, $coinbase ) {
		$address = self::extract_address( $message, $signature );
		return $coinbase === $address;
	}

}
